# The Abaqus Python Development Environment

This section describes the **Abaqus Python development environment** (PDE). The Abaqus PDE provides a simple interface that you can use to develop—create, edit, test, and debug—Python scripts. The Abaqus PDE is primarily intended for use with Abaqus/CAE user interface (GUI) and kernel scripts, including plug-ins, but you can also use it to work on scripts that function independently from Abaqus/CAE.

```{toctree}
:caption: Contents
:maxdepth: 1

about
pde-basics
use-pde
```
